@@ -34,7 +34,10 @@ assert_any_are_credit_card_numbers <- function(x)
 #' @export
 assert_all_are_date_strings <- function(x, format = "%F %T")
 {                                                     
-  msg <- sprintf("%s is not a character vector of dates.", get_name_in_parent(x))
+  msg <- sprintf(
+    "%s is not a character vector of dates.", 
+    get_name_in_parent(x)
+  )
   assert_engine(x, is_date_string, msg, format = format)        
 }
 
@@ -42,7 +45,10 @@ assert_all_are_date_strings <- function(x, format = "%F %T")
 #' @export
 assert_any_are_date_strings <- function(x, format = "%F %T")
 {                                                     
-  msg <- sprintf("%s is not a character vector of dates.", get_name_in_parent(x))
+  msg <- sprintf(
+    "%s is not a character vector of dates.", 
+    get_name_in_parent(x)
+  )
   assert_engine(x, is_date_string, msg, what = "any", format = format)        
 }
 
@@ -64,22 +70,30 @@ assert_any_are_email_addresses <- function(x, method = c("simple", "rfc2822"))
   assert_engine(x, is_email_address, msg, method = method, what = "any")        
 }
 
-#' @rdname is_hex_colour
+#' @rdname is_hex_color
 #' @export
-assert_all_are_hex_colours <- function(x)
+assert_all_are_hex_colors <- function(x)
 {                    
   msg <- sprintf("%s are not all hex colours.", get_name_in_parent(x))
-  assert_engine(x, is_hex_colour, msg)        
+  assert_engine(x, is_hex_color, msg)        
 }
 
-#' @rdname is_hex_colour
+#' @rdname is_hex_color
 #' @export
-assert_any_are_hex_colours <- function(x)
+assert_any_are_hex_colors <- function(x)
 {                                                
   msg <- sprintf("%s are all not hex colours.", get_name_in_parent(x))
-  assert_engine(x, is_hex_colour, msg, what = "any")        
+  assert_engine(x, is_hex_color, msg, what = "any")        
 }
 
+#' @rdname is_hex_color
+#' @export
+assert_all_are_hex_colours <- assert_all_are_hex_colors
+
+#' @rdname is_hex_color
+#' @export
+assert_any_are_hex_colours <- assert_any_are_hex_colors
+
 #' @rdname is_ip_address
 #' @export
 assert_all_are_ip_addresses <- function(x)
@@ -116,7 +130,10 @@ assert_any_are_isbn_codes <- function(x, type = c("10", "13"))
 #' @export
 assert_all_are_numeric_strings <- function(x)
 {                                                     
-  msg <- sprintf("%s is not a character vector of numbers.", get_name_in_parent(x))
+  msg <- sprintf(
+    "%s is not a character vector of numbers.", 
+    get_name_in_parent(x)
+  )
   assert_engine(x, is_numeric_string, msg)        
 }
 
@@ -124,15 +141,37 @@ assert_all_are_numeric_strings <- function(x)
 #' @export
 assert_any_are_numeric_strings <- function(x)
 {                                                     
-  msg <- sprintf("%s is not a character vector of numbers.", get_name_in_parent(x))
+  msg <- sprintf(
+    "%s is not a character vector of numbers.", 
+    get_name_in_parent(x)
+  )
   assert_engine(x, is_numeric_string, msg, what = "any")        
 }
 
+#' @rdname is_single_character
+#' @export
+assert_all_are_single_characters <- function(x)
+{                                                     
+  msg <- sprintf("%s are not all single characters.", get_name_in_parent(x))
+  assert_engine(x, is_single_character, msg)        
+}
+
+#' @rdname is_single_character
+#' @export
+assert_any_are_single_characters <- function(x)
+{                                                     
+  msg <- sprintf("%s are all not single characters.", get_name_in_parent(x))
+  assert_engine(x, is_single_character, msg, what = "any")        
+}
+
 #' @rdname is_character
 #' @export
 assert_all_strings_are_missing_or_empty <- function(x)
 {                                                       
-  msg <- sprintf("%s are not all missing or empty strings.", get_name_in_parent(x))
+  msg <- sprintf(
+    "%s are not all missing or empty strings.", 
+    get_name_in_parent(x)
+  )
   assert_engine(x, is_missing_or_empty_character, msg)
 }
 
@@ -140,13 +179,32 @@ assert_all_strings_are_missing_or_empty <- function(x)
 #' @export
 assert_any_strings_are_missing_or_empty <- function(x)
 {                                                      
-  msg <- sprintf("%s are all not missing or empty strings.", get_name_in_parent(x))
+  msg <- sprintf(
+    "%s are all not missing or empty strings.", 
+    get_name_in_parent(x)
+  )
   assert_engine(x, is_missing_or_empty_character, msg, what = "any")
 }
 
 #' @rdname is_character
 #' @export
 assert_all_strings_are_not_missing_nor_empty <- function(x)
+{                                                       
+  .Deprecated("assert_all_are_not_missing_nor_empty_characters")
+  assert_all_are_not_missing_nor_empty_characters(x)
+}
+
+#' @rdname is_character
+#' @export
+assert_any_strings_are_not_missing_nor_empty <- function(x)
+{                                                      
+  .Deprecated("assert_any_are_not_missing_nor_empty_characters")
+  assert_any_are_not_missing_nor_empty_characters(x)
+}
+
+#' @rdname is_character
+#' @export
+assert_all_are_not_missing_nor_empty_characters <- function(x)
 {                                                       
   msg <- sprintf("%s contains missing or empty strings.", get_name_in_parent(x))
   assert_engine(x, is_not_missing_nor_empty_character, msg)
@@ -154,7 +212,7 @@ assert_all_strings_are_not_missing_nor_empty <- function(x)
 
 #' @rdname is_character
 #' @export
-assert_any_strings_are_not_missing_nor_empty <- function(x)
+assert_any_are_not_missing_nor_empty_characters <- function(x)
 {                                                      
   msg <- sprintf("%s are all missing or empty strings.", get_name_in_parent(x))
   assert_engine(x, is_not_missing_nor_empty_character, msg, what = "any")
@@ -163,29 +221,41 @@ assert_any_strings_are_not_missing_nor_empty <- function(x)
 
 #' @rdname is_valid_variable_name
 #' @export
-assert_all_are_valid_variable_names <- function(x, allow_reserved = TRUE, allow_duplicates = TRUE)
-{                                                       
+assert_all_are_valid_variable_names <- function(x, allow_reserved = TRUE, 
+  allow_duplicates)
+{   
+  if(!missing(allow_duplicates))
+  {
+    .Deprecated(
+      msg = "The 'allow_duplicates' argument is deprecated and will be ignored."
+    )
+  }
   msg <- sprintf("%s are not all valid variable names.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_valid_variable_name, 
     msg,
-    allow_reserved = allow_reserved,
-    allow_duplicates = allow_duplicates
+    allow_reserved = allow_reserved
   )
 }
 
 #' @rdname is_valid_variable_name
 #' @export
-assert_any_are_valid_variable_names <- function(x, allow_reserved = TRUE, allow_duplicates = TRUE)
-{                                                      
+assert_any_are_valid_variable_names <- function(x, allow_reserved = TRUE, 
+  allow_duplicates)
+{          
+  if(!missing(allow_duplicates))
+  {
+    .Deprecated(
+      msg = "The 'allow_duplicates' argument is deprecated and will be ignored."
+    )
+  }
   msg <- sprintf("%s are all not valid variable names.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_valid_variable_name, 
     msg,
     what = "any",
-    allow_reserved = allow_reserved,
-    allow_duplicates = allow_duplicates
+    allow_reserved = allow_reserved
   )
 }
