@@ -10,33 +10,35 @@
 #' CAS registry numbers.
 #' @examples
 #' x <- c(
-#'   water = "7732-18-5", 
-#'   d_glucose = "50-99-7",
-#'   l_glucose = "921-60-8",
-#'   no_hyphens = "7732185", 
+#'   water            = "7732-18-5", 
+#'   d_glucose        = "50-99-7",
+#'   l_glucose        = "921-60-8",
+#'   no_hyphens       = "7732185", 
 #'   two_check_digits = "7732-18-55",
-#'   bad_check_digit = "7732-18-4"
+#'   bad_check_digit  = "7732-18-4",
+#'   missing          = NA
 #' )
 #' is_cas_number(x)
 #' assert_any_are_cas_numbers(x)
-#' \dontrun{
 #' #These examples should fail.
-#' assert_all_are_cas_numbers(x)
-#' }
-#' @references Chemspider is a good service for looking up CAS numbers.
+#' dont_stop(assert_all_are_cas_numbers(x))
+#' @references Chemspider (\url{https://www.chemspider.com}) is a good service 
+#' for looking up CAS numbers.
 #' @export
 is_cas_number <- function(x, .xname = get_name_in_parent(x))
 {
   #Check format
   rx <- c(d(1, 7), d(2), d(1))
   rx <- create_regex(rx, sep = "\\-")
-  
-  ok <- matches_regex(x, rx)
+    
+  ok <- matches <- matches_regex(x, rx)
+
   
   #Check checkdigit
-  x[ok] <- suppressWarnings(strip_non_numeric(x[ok]))
-  ok[ok] <- bapply(
-    character_to_list_of_integer_vectors(x[ok]), 
+  not_missing_and_ok <- !is.na(ok) & ok
+  x[not_missing_and_ok] <- suppressWarnings(strip_non_numeric(x[not_missing_and_ok]))
+  ok[not_missing_and_ok] <- bapply(
+    character_to_list_of_integer_vectors(x[not_missing_and_ok]), 
     function(x)
     {
       lenx <- length(x)
@@ -46,7 +48,7 @@ is_cas_number <- function(x, .xname = get_name_in_parent(x))
       expected_check_digit == actual_check_digit
     }
   )
-  ok
+  set_cause(ok, ifelse(matches, "bad checkdigit", "bad format"))
 }
 
 #' Does the character vector contain credit card numbers? 
@@ -56,10 +58,10 @@ is_cas_number <- function(x, .xname = get_name_in_parent(x))
 #' @param x Input to check.
 #' @param type Type of credit card.  Multiple types can be selected.
 #' @param .xname Not intended to be called directly.
-#' @note Legacy card numbers, for example 13 digit Visa numbers and 15 digits JCB 
-#' numbers are not supported.
-#' @return A logical vector that is \code{TRUE} when the input contains valid credit 
-#' card numbers.
+#' @note Legacy card numbers, for example 13 digit Visa numbers and 15 digits 
+#' JCB numbers are not supported.
+#' @return A logical vector that is \code{TRUE} when the input contains valid 
+#' credit card numbers.
 #' @examples
 #' x <- c(
 #'   #visa
@@ -90,15 +92,15 @@ is_cas_number <- function(x, .xname = get_name_in_parent(x))
 #' )
 #' is_credit_card_number(x)
 #' assert_any_are_credit_card_numbers(x)
-#' \dontrun{
-#' assert_all_are_credit_card_numbers(x)
-#' }
-#' @references \url{http://www.regular-expressions.info/creditcard.html} contains the regexes
-#' used by this function.
+#' dont_stop(assert_all_are_credit_card_numbers(x))
+#' @references \url{http://www.regular-expressions.info/creditcard.html} 
+#' contains the regexes used by this function.
 #' The example valid card numbers are from
 #' \url{http://www.paypalobjects.com/en_US/vhelp/paypalmanager_help/credit_card_numbers.htm}
 #' @export
-is_credit_card_number <- function(x, type = c("visa", "mastercard", "amex", "diners", "discover", "jcb"), .xname = get_name_in_parent(x))
+is_credit_card_number <- function(x, 
+  type = c("visa", "mastercard", "amex", "diners", "discover", "jcb"), 
+  .xname = get_name_in_parent(x))
 {
   #Check format
   type <- match.arg(type, several.ok = TRUE)
@@ -112,13 +114,14 @@ is_credit_card_number <- function(x, type = c("visa", "mastercard", "amex", "din
     jcb        = c(paste0("35", d(2)), rep.int(d(4), 3))
   )
   rx <- create_regex(l = rx[type], sep = " ?")
-  ok <- matches_regex(x, rx)
+  ok <- matches <- matches_regex(x, rx)
+  not_missing_and_ok <- !is.na(ok) & ok
   
-  x[ok] <- suppressWarnings(strip_non_numeric(x[ok]))
+  x[not_missing_and_ok] <- suppressWarnings(strip_non_numeric(x[not_missing_and_ok]))
   
   #Check check digit with Luhn algorithm
-  ok[ok] <- bapply(
-    character_to_list_of_integer_vectors(x[ok]),
+  ok[not_missing_and_ok] <- bapply(
+    character_to_list_of_integer_vectors(x[not_missing_and_ok]),
     function(x)
     {
       lenx <- length(x)
@@ -130,7 +133,10 @@ is_credit_card_number <- function(x, type = c("visa", "mastercard", "amex", "din
       expected_check_digit == actual_check_digit
     }   
   )  
-  ok
+  set_cause(
+    ok, 
+    ifelse(matches, "bad checkdigit", "bad format")
+  )
 }
 
 #' Does the character vector contain dates? 
@@ -138,45 +144,68 @@ is_credit_card_number <- function(x, type = c("visa", "mastercard", "amex", "din
 #' Checks that the input contains dates or times.
 #' 
 #' @param x Input to check.
-#' @param format Expected format of the dates.  See \code{\link[base]{strptime}}.
+#' @param format Expected format of the dates.  See 
+#' \code{\link[base]{strptime}}.
 #' @param .xname Not intended to be called directly.
-#' @return A logical vector that is \code{TRUE} when the input contains valid dates or times.
+#' @return A logical vector that is \code{TRUE} when the input contains valid 
+#' dates or times.
 #' @examples
+#' x <- c("9999-12-31 23:59:59", "wednesday", NA)
+#' is_date_string(x)
 #' assert_all_are_date_strings("01Aug1979", format = "%d%b%Y") #My DOB!
-#' @seealso \code{\link[base]{strptime}} for specifying formats, and the \code{lubridate}
-#' package for automatic guessing of date formats (and other date manipulation functions).
+#' @seealso \code{\link[base]{strptime}} for specifying formats, and the 
+#' \code{lubridate} package for automatic guessing of date formats (and other 
+#' date manipulation functions).
 #' @export
 is_date_string <- function(x, format = "%F %T", .xname = get_name_in_parent(x))
 {
   x <- coerce_to(x, "character")
   format <- use_first(format)
-  f <- function(x) !is.na(strptime(x, format))
-  call_and_name(f, x)  
+  call_and_name(
+    function(x) 
+    {
+      ok <- !is.na(strptime(x, format))
+      set_cause(ok, ifelse(is.na(x), "missing", "bad format"))
+    }, 
+    x
+  )  
 }
 
 #' Does the character vector contain email addresses?
 #' 
-#' Checks that the input contains email addresses.  (It does not check the the address exists, 
-#' merely that the string is in a suitable format.)
+#' Checks that the input contains email addresses.  (It does not check the the 
+#' address exists, merely that the string is in a suitable format.)
 #' 
 #' @param x Input to check.
 #' @param method Name of method to check for validity.  See notes below.
 #' @param .xname Not intended to be called directly.
-#' @note Each method specifies a regular expression (see \code{\link[base]{regex}}) to match 
-#' against. The \code{simple} method matches most email addresses in use, and is quite good at
-#' filtering out typos and nonsense.  It won't match \emph{every} email address however.  For 
-#' example, emails from a top level domain longer than 4 characters won't pass.  The \code{rfc822}
-#' method implements the offical standard for emails.  Thus all genuine emails will pass, but since
-#' the spec is very broad, it isn't as good at filtering out nonsense.
-#' @return A logical vector that is \code{TRUE} when the input contains valid email addresses.
+#' @note Each method specifies a regular expression (see 
+#' \code{\link[base]{regex}}) to match against. The \code{simple} method matches 
+#' most email addresses in use, and is quite good at filtering out typos and 
+#' nonsense.  It won't match \emph{every} email address however.  For example, 
+#' emails from a top level domain longer than 4 characters won't pass.  The 
+#' \code{rfc822} method implements the offical standard for emails.  Thus all 
+#' genuine emails will pass, but since the spec is very broad, it isn't as good 
+#' at filtering out nonsense.
+#' @return A logical vector that is \code{TRUE} when the input contains valid 
+#' email addresses.
 #' @examples
-#' addresses <- c("a@@b.com", "a_at_b.com", "a@@bcom", "a@@b.comma", "a!$&@@b.com")
+#' addresses <- c(
+#'   ok       = "a@@b.com", 
+#'   no_at    = "a_at_b.com", 
+#'   no_dot   = "a@@bcom", 
+#'   long_tld = "a@@b.comma", 
+#'   punct    = "a!$&@@b.com", 
+#'   missing  = NA
+#' )
 #' is_email_address(addresses)
 #' is_email_address(addresses, method = "rfc2822")
-#' @references \url{http://www.regular-expressions.info/email.html} contains the regexes used
-#' by this function and a good discussion of the pros and cons of each.
+#' @references \url{http://www.regular-expressions.info/email.html} contains the 
+#' regexes used by this function and a good discussion of the pros and cons of 
+#' each.
 #' @export
-is_email_address <- function(x, method = c("simple", "rfc2822"), .xname = get_name_in_parent(x))
+is_email_address <- function(x, method = c("simple", "rfc2822"), 
+  .xname = get_name_in_parent(x))
 {
   method <- match.arg(method)
   x <- coerce_to(x, "character")
@@ -185,7 +214,23 @@ is_email_address <- function(x, method = c("simple", "rfc2822"), .xname = get_na
     simple = "^[a-z0-9._%+-]+@[a-z0-9.-]+\\.[a-z]{2,4}$",
     rfc2822 = "(?:[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*|\"(?:[\\x01-\\x08\\x0b\\x0c\\x0e-\\x1f\\x21\\x23-\\x5b\\x5d-\\x7f]|\\\\[\\x01-\\x09\\x0b\\x0c\\x0e-\\x7f])*\")@(?:(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?|\\[(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?|[a-z0-9-]*[a-z0-9]:(?:[\\x01-\\x08\\x0b\\x0c\\x0e-\\x1f\\x21-\\x5a\\x53-\\x7f]|\\\\[\\x01-\\x09\\x0b\\x0c\\x0e-\\x7f])+)\\])"
   )
-  matches_regex(x, rx, perl = TRUE)
+  ok <- matches_regex(x, rx, perl = TRUE)
+  set_cause(ok, "bad format")
+}
+
+#' @rdname is_character
+#' @export
+is_empty_character <- function(x)
+{ 
+  x <- coerce_to(x, "character")
+  call_and_name(
+    function(x)
+    {
+      ok <- !nzchar(x)
+      set_cause(ok, ifelse(is.na(x), "missing", "nonempty"))
+    },
+    x
+  )
 }
 
 #' Does the character vector contain hex colours?
@@ -193,13 +238,14 @@ is_email_address <- function(x, method = c("simple", "rfc2822"), .xname = get_na
 #' Checks that the input contains hexadecimal colours.
 #' 
 #' @param x Input to check.
-#' @note A string is considered to represent a hexadecimal colour when contains a 
-#' hash followed by six hex values.  That is, digits or the letters from a to f 
-#' (case insensitive).
-#' @return A logical vector that is \code{TRUE} when the input contains hex colours.
+#' @note A string is considered to represent a hexadecimal colour when contains 
+#' a hash followed by six hex values.  That is, digits or the letters from a to 
+#' f (case insensitive).
+#' @return A logical vector that is \code{TRUE} when the input contains hex 
+#' colours.
 #' @examples
 #' x <- c(
-#'   "#0123456", "#789abc", "#defDEF", #ok
+#'   "#012345", "#789abc", "#defDEF",  #ok
 #'   "012345",                         #no hash
 #'   "#g12345",                        #bad letter
 #'   "#01 23 45",                      #contains spaces
@@ -207,30 +253,37 @@ is_email_address <- function(x, method = c("simple", "rfc2822"), .xname = get_na
 #' )
 #' is_hex_colour(x)
 #' assert_any_are_hex_colours(x)
-#' \dontrun{
 #' #These examples should fail.
-#' assert_all_are_hex_colours(x)
-#' }
+#' dont_stop(assert_all_are_hex_colours(x))
 #' @export
-is_hex_colour <- function(x)
+is_hex_color <- function(x)
 {
   rx <- create_regex("#[0-9a-f]{6}")
-  matches_regex(x, rx)
+  ok <- matches_regex(x, rx)
+  set_cause(ok, "bad format")
 }
-       #' Is the string an honorific?
+
+#' @rdname is_hex_color
+#' @export
+is_hex_colour <- is_hex_color
+
+#' Is the string an honorific?
 #' 
 #' Checks that the input contains honorifics (a.k.a. titles 
 #' or salutations).
 #' @param x Input to check.
 #' @return \code{is_honorific} returns \code{TRUE} if the input string contains
-#' a valid UK postcode. The {assert_*} function returns nothing but throws an error 
-#' when the \code{is_*} function returns \code{FALSE}. 
+#' a valid UK postcode. The {assert_*} function returns nothing but throws an 
+#' error when the \code{is_*} function returns \code{FALSE}. 
 #' @note Single full stops (periods) following a word boundary 
 #' and preceding a space or the end of the string are stripped.  
 #' Case is ignored.  There is no formal list of official salutations,
 #' so this should only be used as a guide, rather than giving a 
 #' definitive result.  Especially note that cultural conventions
 #' differ across the world and this function has a UK bias.
+#' @references Many possibilities borrowed from the Salutation dropdown on
+#' the MathWorks account creation page.
+#' \url{https://www.mathworks.com/accesslogin/createProfile.do}
 #' @examples
 #' x <- c("Mr", "MR", "mr.", "Mister", "masTer", "Mr!", "M.r", ".Mr")
 #' is_honorific(x)
@@ -240,29 +293,44 @@ is_honorific <- function(x)
   #Strip single dots after words
   x <- gsub("(?<=\\b)\\.(?=\\s|$)", "", x, perl = TRUE)  
   rx <- create_regex(
-    #standard
-    "m([ia]ste)?r", "mrs", "miss", "d(octo)?r", 
-    #academic
+    # standard
+    "m([ia]ste)?r", "mrs", "m(is)?s", "d(octo)?r", 
+    # academic
     "((assoc)?iate)prof(essor)?", "dean", 
-    #religious
+    # religious
     "rev(erend)?", "ft", "father", "bro(ther)?", "s(iste)?r", "(arch)?bishop", 
-    #politics and nobility
-    "r(igh)?t hon(ourable)", "sir", "lord", "lady", "dame", "prince(ss)?", "king", "queen"#,
-    #military 
-    #TODO "", "", "", "", "", "", ""
+    # politics and nobility
+    "r(igh)?t hon(ourable)", "sir", "lord", "lady", "dame", "prince(ss)?", "king", "queen",
+    # military 
+    "adm(iral)", "brig(adier )?gen(eral)?", "capt(ain)?", "cdr", "commander", 
+    "cpt", "eur ing", "gen(eral)?", "ltc?", "lieutenant( commander| general)?", 
+    "lt cdr", "ltjg", "maj(or)?( general)?", "mgen", "radm", "rag", "(staf )?sgt", 
+    "sergeant",  "[12]lt",
+    # french
+    "mlle", "mme", "m",
+    # german
+    "herr", "frau",
+    # dutch
+    "heer", "mevrouw",
+    # italian
+    "sig( ra)?",
+    # spanish
+    "sr(ta|a)?"
   )
-  matches_regex(x, rx)
+  ok <- matches_regex(x, rx)
+  set_cause(ok, "bad format")
 }
 
 #' Does the character vector contain IP addresses?
 #' 
-#' Checks that the input contains IP addresses.  (It does not check that the address exists, 
-#' merely that the string is in a suitable format.)
+#' Checks that the input contains IP addresses.  (It does not check that the 
+#' address exists, merely that the string is in a suitable format.)
 #' 
 #' @param x Input to check.
-#' @note Valid IP addresses are considered to be four integers in the range 0 to 255, separated
-#' by dots, or the string "localhost".
-#' @return A logical vector that is \code{TRUE} when the input contains valid IP addresses.
+#' @note Valid IP addresses are considered to be four integers in the range 0 to 
+#' 255, separated by dots, or the string "localhost".
+#' @return A logical vector that is \code{TRUE} when the input contains valid IP 
+#' addresses.
 #' @examples
 #' x <- c(
 #'   localhost     = "localhost", 
@@ -270,79 +338,107 @@ is_honorific <- function(x)
 #'   out_of_range  = "1.2.3.256",
 #'   five_blocks   = "1.2.3.4.5",
 #'   non_numeric   = "1.2.3.Z",
-#'   missing_block = "1.2.3.NA"
+#'   missing_block = "1.2.3.NA",
+#'   missing       = NA
 #' )
 #' is_ip_address(x)
 #' assert_any_are_ip_addresses(x)
-#' \dontrun{
 #' #These examples should fail.
-#' assert_all_are_ip_addresses(x)
-#' }
+#' dont_stop(assert_all_are_ip_addresses(x))
 #' @export
 is_ip_address <- function(x)
 {
   x <- coerce_to(x, "character")  
   rx <- create_regex(rep.int(d(1, 3), 4), sep = "\\.")
-  ok <- matches_regex(x, rx)
+  ok <- matches <- matches_regex(x, rx)
+  not_missing_and_ok <- !is.na(ok) & ok
   
-  blocks <- strsplit(x[ok], ".", fixed = TRUE)
-  ok[ok] <- bapply(
+  blocks <- strsplit(x[not_missing_and_ok], ".", fixed = TRUE)
+  ok[not_missing_and_ok] <- bapply(
     blocks,
-    function(b) all(suppressWarnings(as.integer(b) %in% 0:255))
+    function(b) 
+    {  
+      all(suppressWarnings(as.integer(b) %in% 0:255))
+    }
   )
   
-  ok | (x == "localhost")
+  ok <- ok | (x == "localhost")
+  set_cause(ok, ifelse(matches, "big numbers", "bad format"))
 }
 
 #' @rdname is_isbn_code
+#' @export
 is_isbn10_code <- function(x, .xname = get_name_in_parent(x))
 {
   #Check basic format
-  digits <- "[[:digit:]]+"
-  sep <- "[- ]?"
-  rx <- create_regex(c(rep.int(digits, 3), "[[:digit:]X]"))
-  ok <- matches_regex(x, rx)
+  rx <- create_regex(c(rep.int(d(1, Inf), 3), "[[:digit:]X]"))
+  ok <- matches <- matches_regex(x, rx)
+  not_missing_and_ok <- !is.na(ok) & ok
   
   #Check correct amount of numbers
-  x[ok] <- suppressWarnings(strip_non_numeric(x[ok], allow_x = TRUE))
-  ok[ok] <- nchar(x[ok]) == 10L
+  x[not_missing_and_ok] <- suppressWarnings(
+    strip_non_numeric(x[not_missing_and_ok], allow_x = TRUE)
+  )
+  ok[not_missing_and_ok] <- len <- nchar(x[not_missing_and_ok]) == 10L
+  not_missing_and_still_ok <- !is.na(ok) & ok
   
   #Check checkdigit
-  ok[ok] <- bapply(
-    character_to_list_of_integer_vectors(x[ok]),
+  ok[not_missing_and_still_ok] <- bapply(
+    character_to_list_of_integer_vectors(x[not_missing_and_still_ok]),
     function(x)
     {
       actual_check_digit <- x[10L]
-      x <- x[1:9L]
+      x <- x[-10L]
       expected_check_digit <- (sum(x * 1:9L) %% 11L)
-      if(expected_check_digit == 10L) return(is.na(actual_check_digit))
+      if(expected_check_digit == 10L) 
+      {
+        return(is.na(actual_check_digit))
+      }
       expected_check_digit == actual_check_digit
     }
   )  
-  ok
+  set_cause(
+    ok, 
+    ifelse(
+      not_missing_and_still_ok,
+      "bad check digit",
+      ifelse(not_missing_and_ok, "bad length", "bad format")
+    )
+  )
 }
 
 #' @rdname is_isbn_code
+#' @export
 is_isbn13_code <- function(x, .xname = get_name_in_parent(x))
 {
   #Check basic format
-  digits <- "[[:digit:]]+"
-  rx <- create_regex(c(rep.int(digits, 4), "[[:digit:]X]"))
-  ok <- matches_regex(x, rx)
+  rx <- create_regex(c(rep.int(d(1, Inf), 4), "[[:digit:]X]"))
+  ok <- matches <- matches_regex(x, rx)
+  not_missing_and_ok <- !is.na(ok) & ok
   
   #Check correct amount of numbers
-  x[ok] <- suppressWarnings(strip_non_numeric(x[ok]))
-  ok[ok] <- nchar(x[ok]) == 13L
+  x[not_missing_and_ok] <- suppressWarnings(
+    strip_non_numeric(x[not_missing_and_ok], allow_x = TRUE)
+  )
+  ok[not_missing_and_ok] <- len <- nchar(x[not_missing_and_ok]) == 13L
+  not_missing_and_still_ok <- !is.na(ok) & ok
   
   #Check checkdigit
-  ok[ok] <- bapply(
-    character_to_list_of_integer_vectors(x[ok]),
+  ok[not_missing_and_still_ok] <- bapply(
+    character_to_list_of_integer_vectors(x[not_missing_and_still_ok]),
     function(x)
     {
       (sum(suppressWarnings(x * c(1, 3))) %% 10L) == 0L
     }
   )  
-  ok
+  set_cause(
+    ok, 
+    ifelse(
+      not_missing_and_still_ok,
+      "bad check digit",
+      ifelse(not_missing_and_ok, "bad length", "bad format")
+    )
+  )
 }
 
 #' Does the character vector contain ISBN book codes?
@@ -352,7 +448,8 @@ is_isbn13_code <- function(x, .xname = get_name_in_parent(x))
 #' @param x Input to check.
 #' @param type Either "isbn10", "isbn13" or both (for matching either type).
 #' @param .xname Not intended to be called directly.
-#' @return  A logical vector that is \code{TRUE} when the input contains valid ISBN book codes.
+#' @return  A logical vector that is \code{TRUE} when the input contains valid 
+#' ISBN book codes.
 #' @examples
 #' x10 <- c(
 #'   hyphens             = "0-387-98503-4",
@@ -361,7 +458,8 @@ is_isbn13_code <- function(x, .xname = get_name_in_parent(x))
 #'   too_long            = "00-387-98503-4",
 #'   too_short           = "0-387-9850-4",
 #'   non_numeric         = "Z-387-98503-4",
-#'   invalid_check_digit = "0-387-98503-5"
+#'   invalid_check_digit = "0-387-98503-5",
+#'   missing             = NA
 #' )
 #' x13 <- c(
 #'   hyphens             = "978-0-387-98503-9",
@@ -370,19 +468,19 @@ is_isbn13_code <- function(x, .xname = get_name_in_parent(x))
 #'   too_long            = "9978-0-387-98503-9",
 #'   too_short           = "978-0-387-9850-9",
 #'   non_numeric         = "Z78-0-387-9850-9",
-#'   invalid_check_digit = "978-0-387-98503-8"
+#'   invalid_check_digit = "978-0-387-98503-8",
+#'   missing             = NA
 #' )
 #' is_isbn_code(x10, type = "10")
 #' assert_any_are_isbn_codes(x10, type = "10")
 #' is_isbn_code(x13, type = "13")
 #' assert_any_are_isbn_codes(x13, type = "13")
-#' \dontrun{
 #' #These tests should fail.
-#' assert_all_are_isbn_codes(x10, type = "10")
-#' assert_all_are_isbn_codes(x13, type = "13")
-#' }
+#' dont_stop(assert_all_are_isbn_codes(x10, type = "10"))
+#' dont_stop(assert_all_are_isbn_codes(x13, type = "13"))
 #' @export
-is_isbn_code <- function(x, type = c("10", "13"), .xname = get_name_in_parent(x))
+is_isbn_code <- function(x, type = c("10", "13"), 
+  .xname = get_name_in_parent(x))
 {
   type <- match.arg(type, several.ok = TRUE)
   ok <- lapply(
@@ -405,7 +503,8 @@ is_isbn_code <- function(x, type = c("10", "13"), .xname = get_name_in_parent(x)
 is_missing_or_empty_character <- function(x)
 { 
   x <- coerce_to(x, "character")
-  !nzchar(x) | is_na(x)
+  ok <- !nzchar(x) | is_na(x)
+  set_cause(ok, "nonempty")
 }
 
 #' @rdname is_character
@@ -413,7 +512,8 @@ is_missing_or_empty_character <- function(x)
 is_not_missing_nor_empty_character <- function(x)
 { 
   x <- coerce_to(x, "character")
-  nzchar(x) & !is_na(x)
+  ok <- nzchar(x) & !is_na(x)
+  set_cause(ok, ifelse(is.na(x), "missing", "empty"))
 }
 
 #' @rdname is_character
@@ -421,10 +521,41 @@ is_not_missing_nor_empty_character <- function(x)
 is_numeric_string <- function(x)
 {
   x <- coerce_to(x, "character")
-  numx <- suppressWarnings(as.numeric(x))
-  ans <- is_not_na(numx)
-  names(ans) <- x   #need to take names from x, not numx
-  ans
+  ok <- call_and_name(
+    function(x)
+    {
+      numx <- suppressWarnings(as.numeric(x))
+      is_not_na(numx)
+    },
+    x
+  )
+  set_cause(ok, ifelse(is.na(x), "missing", "bad format"))
+}
+
+#' Is the input a single character?
+#' 
+#' Checks to see if he unput is a single character.
+#' @param x A character vector.
+#' @return \code{is_single_character} returns \code{TRUE} when the input is a 
+#' single character (as determined by \code{nchar}; this excludes \code{NA}).
+#' The \code{assert_*} functions return nothing but throw an error if the 
+#' corresponding \code{is_*} function returns \code{FALSE}.
+#' @seealso \code{\link[base]{nchar}}
+#' @examples
+#' x <- c("", "a", "aa", NA)
+#' is_single_character(x)
+#' @export
+is_single_character <- function(x)
+{
+  x <- coerce_to(x, "character")
+  ok <- call_and_name(
+    function(x)
+    {
+      nchar(x) == 1
+    },
+    x
+  )
+  set_cause(ok, ifelse(is.na(x), "missing", "bad format"))  
 }
 
 #' Is the input valid R code?
@@ -463,43 +594,64 @@ is_valid_r_code <- function(x, .xname = get_name_in_parent(x))
 #' @param x Input to check.
 #' @param allow_reserved If \code{TRUE} then "..." and "..1", "..2", etc. 
 #' are considered valid.
-#' @param allow_duplicates If \code{TRUE} then duplicated names are allowed.
-#' @return \code{TRUE} if the input is a valid variable name.
-#' The \code{assert_*} functions return nothing but
-#' throw an error if the corresponding \code{is_*} function returns 
-#' \code{FALSE}.
+#' @param allow_duplicates Deprecated and ignored.
+#' The \code{assert_*} functions return nothing but throw an error if the 
+#' corresponding \code{is_*} function returns \code{FALSE}.
 #' @seealso \code{\link{make.names}}.
 #' @examples
-#' assert_all_are_valid_variable_names(c("x", "y_y0.y", ".", "...", "..1"))
-#' \dontrun{
-#' #These examples should fail.
-#' assert_all_are_valid_variable_names(c("...", "..1"), allow_reserved = FALSE) 
-#' assert_all_are_valid_variable_names(c("x", "x"), allow_duplicates = FALSE)
+#' make_random_string <- function(n)
+#' {
+#'   paste0(sample(letters, n, replace = TRUE), collapse = "")
 #' }
+#' long <- c(make_random_string(10000), make_random_string(10001))
+#' x <- c("x", "y_y0.Y", ".", "x y", "...", "..1", long)
+#' is_valid_variable_name(x)
+#' is_valid_variable_name(x, allow_reserved = FALSE)
+#' #These examples should fail.
+#' dont_stop(assert_all_are_valid_variable_names(c("...", "..1"), allow_reserved = FALSE))
 #' @references
 #' \url{http://4dpiecharts.com/2011/07/04/testing-for-valid-variable-names/}
 #' @export
-is_valid_variable_name <- function(x, allow_reserved = TRUE, allow_duplicates = TRUE)
+is_valid_variable_name <- function(x, allow_reserved = TRUE, 
+  allow_duplicates)
 {
+  if(!missing(allow_duplicates))
+  {
+    .Deprecated(
+      msg = "The 'allow_duplicates' argument is deprecated and will be ignored."
+    )
+  }
   x <- coerce_to(x, "character")
-  ok <- rep.int(TRUE, length(x))
   
   #is name too long?
   max_name_length <- if(getRversion() < "2.13.0") 256L else 10000L
-  ok[ok] <- nchar(x[ok]) <= max_name_length
+  ok <- short_enough <- nchar(x) <= max_name_length
+  
+  not_missing_and_ok <- !is.na(ok) & ok
   
   #is it a reserved variable, i.e.
   #an ellipsis or two dots then a number?
+  not_reserved <- rep.int(TRUE, length(x))
   if(!allow_reserved)
   {
-    ok[ok] <- x[ok] != "..."
     rx <- create_regex("\\.{2}[[:digit:]]+")
-    ok[ok] <- !matches_regex(x[ok], rx)
-  }
+    ok[not_missing_and_ok] <- not_reserved[not_missing_and_ok] <- 
+      x[not_missing_and_ok] != "..." & !matches_regex(x[not_missing_and_ok], rx)
+  } 
   
   #are names valid (and maybe unique)
-  ok[ok] <- x[ok] == make.names(x[ok], unique = !allow_duplicates)
+  not_missing_and_ok <- !is.na(ok) & ok
+  
+  ok[not_missing_and_ok] <- x[not_missing_and_ok] == 
+    make.names(x[not_missing_and_ok])
   
   names(ok) <- x
-  ok
+  set_cause(
+    ok, 
+    ifelse(
+      short_enough, 
+      ifelse(not_reserved, "bad format", "reserved"),
+      "too long"  
+    )
+  )
 }
